pub enum SocketReconnectLookup {
ClientNotFound,
Unsupported,
EndpointNotFound,
AmbiguousEndpoint,
Handle(SocketReconnectHandle),
}Expand description
Outcome from resolving a client socket through a live node registry.
Variants
ClientNotFound
No client with the requested ID belongs to the live node.
Unsupported
The client has no controller-reconnectable sockets.
EndpointNotFound
The client supports socket reconnects but not for the requested endpoint.
AmbiguousEndpoint
More than one client surface owns the requested endpoint.
Handle(SocketReconnectHandle)
The endpoint resolved to one reconnect handle.