pub struct SocketControlFactory { /* private fields */ }Expand description
Creates socket controls which share client identity and registry ownership.
Implementations
Sourceimpl SocketControlFactory
impl SocketControlFactory
Sourcepub fn new(client_id: ClientId, venue: Option<Venue>) -> Self
pub fn new(client_id: ClientId, venue: Option<Venue>) -> Self
Creates a new SocketControlFactory instance.
Sourcepub fn with_registry(
client_id: ClientId,
venue: Option<Venue>,
registry: &SocketReconnectRegistry,
) -> Self
pub fn with_registry( client_id: ClientId, venue: Option<Venue>, registry: &SocketReconnectRegistry, ) -> Self
Creates a factory which registers with an explicit live socket registry.
Sourcepub fn control(&self, endpoint: impl AsRef<str>) -> SocketControl
pub fn control(&self, endpoint: impl AsRef<str>) -> SocketControl
Creates a control for one logical socket endpoint.