pub struct SocketReconnectRegistry { /* private fields */ }Expand description
Registry of reconnectable socket endpoints owned by one live node.
Implementations
Sourceimpl SocketReconnectRegistry
impl SocketReconnectRegistry
Sourcepub fn scope<T>(&self, f: impl FnOnce() -> T) -> T
pub fn scope<T>(&self, f: impl FnOnce() -> T) -> T
Makes this registry available while live client factories construct their clients.
Sourcepub fn get(&self, client_id: ClientId, endpoint: Ustr) -> SocketReconnectLookup
pub fn get(&self, client_id: ClientId, endpoint: Ustr) -> SocketReconnectLookup
Resolves one logical socket endpoint.
Sourcepub fn handle(
&self,
client_id: ClientId,
endpoint: Ustr,
) -> Option<SocketReconnectHandle>
pub fn handle( &self, client_id: ClientId, endpoint: Ustr, ) -> Option<SocketReconnectHandle>
Returns the reconnect handle when exactly one owner registered endpoint.